/*
  Express app config file, be sure to call npm install before attempting to run the server
*/
var express = require('express');
var session = require('express-session');
var FileStore = require('session-file-store')(session);
var path = require('path');
var favicon = require('serve-favicon');
var logger = require('morgan');
var bodyParser = require('body-parser');
var busboy = require('connect-busboy');
var tmp = require('tmp');
var app = express();

//we use busboy to get the file streams from the browser for uploads
app.use(busboy());

// view engine setup
app.set('views', path.join(__dirname, 'views'));
app.set('view engine', 'jade');

//setup persistent sessions so we dont have to keep reauthenticating every time we refresh, /logout will kill the session
app.use(session({
  secret: 'jPJyCqgRWzsWiBbtppqP',
  saveUninitialized: false,
  resave: false,
  store: new FileStore({})
}));

//add our cloud helper function to the app checkout cloud.js which wraps the SDK and returns instances of it for clients to use
app.locals.cloud = require('./cloud.js');

app.use(logger('dev'));
app.use(bodyParser.json());
app.use(bodyParser.urlencoded({ extended: false }));
app.use(express.static(path.join(__dirname, 'public')));

//load all routers in ./routes and pass the app instance to them in the require
require('./routes/auth.js')(app);
require('./routes/fileops.js')(app);
require('./routes/upload.js')(app);
require('./routes/playlist.js')(app);
require('./routes/contacts.js')(app);
require('./routes/trash.js')(app);
require('./routes/shares.js')(app);
require('./routes/console.js')(app);


// catch 404 and forward to error handler
app.use(function(req, res, next) {
  var err = new Error('Not Found');
  err.status = 404;
  next(err);
});


// error handlers
// development error handler
// will print stacktrace
if (app.get('env') === 'development') {
  app.use(function(err, req, res, next) {
    res.status(err.status || 500);
    res.render('error', {
      message: err.message,
      error: err
    });
  });
}

// production error handler
// no stacktraces leaked to user
app.use(function(err, req, res, next) {
  res.status(err.status || 500);
  res.render('error', {
    message: err.message,
    error: {}
  });
});

module.exports = app;