/*
	all routes pertaining to file ops stuff, fullview, metadata, and upload operations
*/
module.exports = function(router) {

	/*
		router that fetchs all files and folders in a user's cloud account
	*/
	router.get('/files', function(req, res, next) {	
		sess=req.session;
		console.log(sess);	
		if(!sess.loggedIn) {
			res.redirect('/');
			return;
		}

		var cloud =  req.app.locals.cloud(req);		

		cloud.fullview({
			success: function(resp) {
				res.render('files', { 
					cloud: cloud, //pass the template the cloud object so it can get download URLs
					files: resp.body.data.file  //pass the template all the files in the user's accounnt
				});
			},
			failure: function(resp) {
				res.render('files', { 
					error: "Error calling fullview" 
				});
			}
		});
	});


	/*
		Basic file explorer router, uses the metadata call to traverse the directories in a user's Cloud account
	*/
	router.get('/metadata*', function(req, res, next) {	
		sess=req.session;
		console.log(sess);

		if(!sess.loggedIn) {
			res.redirect('/');
			return;
		}

		var cloud =  req.app.locals.cloud(req);		
		var path = req.params[0];
		if(!path) {
			path = '/';
		}
		console.log("path", path);

		//tokenizes a long path like /VZMOBILE/test/folder/2 into ['/', 'VZMOBILE', 'test', 'folder', '2']
		var partsofPath = partsOfPathHelper(path);

		cloud.metadata({
			path: path,
			success: function(resp) {
				console.log(resp);
				res.render('metadata', { 
					cloud: cloud,
					path: path,
					files: resp.body.folder.file,
					folders: resp.body.folder.folder,
					filePaths: partsofPath,
					//helper function used by the template to get human readable representations of paths
					pathToFolderString : pathToFolderStringHelper
				});

			}, 
			failure: function(resp) {
				res.render('metadata', { 
					error: "Error calling fullview" 
				});
			}
		});
	});













	/*
		helper functions

	*/

	//helper function used by the template to get human readable representations of paths
	var pathToFolderStringHelper = function(path) {
		if(path == "/") {
			return "/";
		}
		var pathWithoutTrailingSlash = path.substring(0, path.length - 1);
		return pathWithoutTrailingSlash.substring(pathWithoutTrailingSlash.lastIndexOf("/") + 1);
	}

	//tokenizes a path string like /VZMOBILE/test/folder/2 into ['/', 'VZMOBILE', 'test', 'folder', '2']
	var partsOfPathHelper = function(path) {
		var partsofPath = [];
		var slashIndex = path.indexOf("/");

		while(slashIndex != -1) {
			var nextSlashIndex = path.indexOf("/", slashIndex + 1);
			partsofPath.push(path.substring(0,slashIndex+ 1));
			slashIndex = nextSlashIndex;
		}
		return partsofPath;
	} 
}